==> owlapi-api-3.4.10-sources.jar: org/semanticweb/owlapi/model/DataRangeType.java <==
/*
 * This file is part of the OWL API.
 *
 * The contents of this file are subject to the LGPL License, Version 3.0.
 *
 * Copyright (C) 2011, The University of Manchester
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0
 * in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 *
 * Copyright 2011, University of Manchester
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.semanticweb.owlapi.model;

import java.io.Serializable;

/** Represents the different types of OWL 2 data ranges.
 * 
 * @author Matthew Horridge, The University of Manchester, Information
 *         Management Group */
public enum DataRangeType implements Serializable {
    /** Represents {@link org.semanticweb.owlapi.model.OWLDatatype} */
    DATATYPE("Datatype"),
    /** Represents {@link OWLDataOneOf} */
    DATA_ONE_OF("DataOneOf"),
    /** Represents {@link OWLDatatypeRestriction} */
    DATATYPE_RESTRICTION("DatatypeRestriction"),
    /** Represents {@link OWLDataComplementOf} */
    DATA_COMPLEMENT_OF("DataComplementOf"),
    /** Represents {@link OWLDataUnionOf} */
    DATA_UNION_OF("DataUnionOf"),
    /** Represents {@link OWLDataIntersectionOf} */
    DATA_INTERSECTION_OF("DataIntersectionOf");
    private final String name;

    DataRangeType(String name) {
        this.name = name;
    }

    /** @return the name */
    public String getName() {
        return name;
    }
}

==> owlapi-api-3.5.0-sources.jar: org/semanticweb/owlapi/model/DataRangeType.java <==
/*
 * This file is part of the OWL API.
 *
 * The contents of this file are subject to the LGPL License, Version 3.0.
 *
 * Copyright (C) 2011, The University of Manchester
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0
 * in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 *
 * Copyright 2011, University of Manchester
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.semanticweb.owlapi.model;

import org.semanticweb.owlapi.vocab.Namespaces;

import java.io.Serializable;

/**
 * Represents the different types of OWL 2 data ranges.
 * 
 * @author Matthew Horridge, The University of Manchester, Information
 *         Management Group
 */
public enum DataRangeType
        implements
        Serializable,
        HasShortForm,
        HasPrefixedName,
        HasIRI {
    /** Represents {@link org.semanticweb.owlapi.model.OWLDatatype} */
    DATATYPE("Datatype"),
    /** Represents {@link OWLDataOneOf} */
    DATA_ONE_OF("DataOneOf"),
    /** Represents {@link OWLDatatypeRestriction} */
    DATATYPE_RESTRICTION("DatatypeRestriction"),
    /** Represents {@link OWLDataComplementOf} */
    DATA_COMPLEMENT_OF("DataComplementOf"),
    /** Represents {@link OWLDataUnionOf} */
    DATA_UNION_OF("DataUnionOf"),
    /** Represents {@link OWLDataIntersectionOf} */
    DATA_INTERSECTION_OF("DataIntersectionOf");

    private final String name;
    private final String prefixedName;
    private final IRI iri;

    DataRangeType(String name) {
        this.name = name;
        this.prefixedName = Namespaces.OWL.getPrefixName() + ":" + name;
        this.iri = IRI.create(Namespaces.OWL.getPrefixIRI(), name);
    }

    /** @return the name */
    public String getName() {
        return name;
    }

    @Override
    public String getShortForm() {
        return name;
    }

    @Override
    public IRI getIRI() {
        return iri;
    }

    @Override
    public String getPrefixedName() {
        return prefixedName;
    }
}
